xaal.homekit
============
This package provides a HomeKit / xAAL Gateway. This is a preliminary version. We are looking for feedbacks and contributions.
The gateway loose the connection with the HomeKit bridge after a while.
